@@ -62,12 +62,15 @@ from __future__ import annotations
 
 import asyncio
 import copy
-from typing import Any, AsyncIterator, Callable, Iterator, Mapping, Type
+from typing import TYPE_CHECKING, Any
 
 import aiohttp
 import uritemplate
 
 
+if TYPE_CHECKING:
+    from collections.abc import AsyncIterator, Callable, Iterator, Mapping
+
 try:
     aiter  # noqa: B018
 except NameError:  # Python 3.7
@@ -548,7 +551,7 @@ class References:
         except AttributeError:
             return self[key]
 
-    def __get__(self, obj: Any, cls: Type | None = None) -> References:
+    def __get__(self, obj: Any, cls: type | None = None) -> References:
         return type(self)(obj)
 
 
@@ -791,4 +794,4 @@ class PatchDocument:
         })
 
     def expand_path(self, path_segments):
-        return '/'.join(path.replace('~', '~0').replace('/', '~1') for path in [''] + path_segments)
+        return '/'.join(path.replace('~', '~0').replace('/', '~1') for path in ['', *path_segments])
