@@ -738,7 +738,9 @@ class _OpenAPIBase:
                         {'$ref': '#/components/parameters/objects.get.query.query'},
                         {'$ref': '#/components/parameters/objects.get.query.hidden'},
                         {'$ref': '#/components/parameters/objects.get.query.properties'},
-                    ] + pagination_parameters + global_parameters,
+                        *pagination_parameters,
+                        *global_parameters,
+                    ],
                     "responses": global_responses({
                         200: {
                             '$ref': '#/components/responses/objects.%s.get.response.success' % (_openapi_quote(model_name),),
@@ -763,7 +765,8 @@ class _OpenAPIBase:
                         {'$ref': '#/components/parameters/template.get.query.position'},
                         {'$ref': '#/components/parameters/template.get.query.superordinate'},
                         {'$ref': '#/components/parameters/template.get.query.template'},
-                    ] + global_parameters,
+                        *global_parameters,
+                    ],
                     "responses": global_responses({
                         200: {
                             '$ref': '#/components/responses/template.%s.get.response.success' % (_openapi_quote(model_name),),
@@ -782,7 +785,7 @@ class _OpenAPIBase:
                     "requestBody": {
                         "$ref": schema_request_body,
                     },
-                    "parameters": [] + global_parameters,
+                    "parameters": [*global_parameters],
                     "responses": global_responses({
                         201: {
                             '$ref': '#/components/responses/objects.post.response.created',
@@ -796,7 +799,8 @@ class _OpenAPIBase:
                 "parameters": [
                     {'$ref': '#/components/parameters/object.get.query.properties'},
                     # {'$ref': '#/components/parameters/object.get.query.copy'},
-                ] + global_parameters,
+                    *global_parameters,
+                ],
                 "responses": global_responses({
                     "200": {
                         '$ref': '#/components/responses/object.%s.get.response.success' % (_openapi_quote(model_name),),
@@ -825,7 +829,8 @@ class _OpenAPIBase:
                         {'$ref': '#/components/parameters/object.delete.query.recursive'},
                         {'$ref': '#/components/parameters/if-match'},
                         {'$ref': '#/components/parameters/if-unmodified-since'},
-                    ] + global_parameters,
+                        *global_parameters,
+                    ],
                     "responses": global_responses({
                         "204": {
                             '$ref': '#/components/responses/object.delete.response.nocontent',
@@ -846,7 +851,8 @@ class _OpenAPIBase:
                     "parameters": [
                         {'$ref': '#/components/parameters/if-match'},
                         {'$ref': '#/components/parameters/if-unmodified-since'},
-                    ] + global_parameters,
+                        *global_parameters,
+                    ],
                     "callbacks": {
                         'move-progress': {
                             '$ref': '#/components/callbacks/moveProgress',
@@ -877,7 +883,8 @@ class _OpenAPIBase:
                     "parameters": [
                         {'$ref': '#/components/parameters/if-match'},
                         {'$ref': '#/components/parameters/if-unmodified-since'},
-                    ] + global_parameters,
+                        *global_parameters,
+                    ],
                     "responses": global_responses({
                         "204": {
                             '$ref': '#/components/responses/object.patch.response.nocontent',
